@@ -184,11 +184,13 @@ mkdir 'out' 'inst' || exit 1
 		done
 
 		## Also create an executable named "kit" so that we can run it later
-		${MAKE:-make} tclsh
+		eval tclshExtraMakeArgs=(${KC_KITSH_TCLSH_EXTRA_MAKE_ARGS})
+		echo "Running: ${MAKE:-make} tclsh ${tclshExtraMakeArgs[@]}"
+		${MAKE:-make} tclsh "${tclshExtraMakeArgs[@]}"
 		if [ -f "tclsh.exe" ]; then
-			mv tclsh.exe kit.exe
+			cp tclsh.exe kit.exe
 		else
-			mv tclsh kit
+			cp tclsh kit
 		fi
 	else
 		## The executable is always named "kit"
